==> ginkgo-hpc-docs-1.7.0-5-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_8.js <==
var searchData=
[
  ['ic_0',['Ic',['../classgko_1_1factorization_1_1Ic.html',1,'gko::factorization::Ic&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Ic.html',1,'gko::preconditioner::Ic&lt; LSolverType, IndexType &gt;']]],
  ['identity_1',['Identity',['../classgko_1_1batch_1_1matrix_1_1Identity.html',1,'gko::batch::matrix::Identity&lt; ValueType &gt;'],['../classgko_1_1matrix_1_1Identity.html',1,'gko::matrix::Identity&lt; ValueType &gt;']]],
  ['identityfactory_2',['IdentityFactory',['../classgko_1_1matrix_1_1IdentityFactory.html',1,'gko::matrix']]],
  ['idr_3',['Idr',['../classgko_1_1solver_1_1Idr.html',1,'gko::solver']]],
  ['ilu_4',['Ilu',['../classgko_1_1factorization_1_1Ilu.html',1,'gko::factorization::Ilu&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Ilu.html',1,'gko::preconditioner::Ilu&lt; LSolverType, USolverType, ReverseApply, IndexType &gt;']]],
  ['imag_5foperation_5',['imag_operation',['../structgko_1_1accessor_1_1imag__operation.html',1,'gko::accessor']]],
  ['imag_5foperaton_6',['imag_operaton',['../structgko_1_1accessor_1_1imag__operaton.html',1,'gko::accessor']]],
  ['imbalance_5fbounded_5flimit_7',['imbalance_bounded_limit',['../classgko_1_1matrix_1_1Hybrid_1_1imbalance__bounded__limit.html',1,'gko::matrix::Hybrid']]],
  ['imbalance_5flimit_8',['imbalance_limit',['../classgko_1_1matrix_1_1Hybrid_1_1imbalance__limit.html',1,'gko::matrix::Hybrid']]],
  ['implicitresidualnorm_9',['ImplicitResidualNorm',['../classgko_1_1stop_1_1ImplicitResidualNorm.html',1,'gko::stop']]],
  ['index_5fset_10',['index_set',['../classgko_1_1index__set.html',1,'gko']]],
  ['invalidstateerror_11',['InvalidStateError',['../classgko_1_1InvalidStateError.html',1,'gko']]],
  ['ir_12',['Ir',['../classgko_1_1solver_1_1Ir.html',1,'gko::solver']]],
  ['isai_13',['Isai',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['iteration_14',['Iteration',['../classgko_1_1stop_1_1Iteration.html',1,'gko::stop']]],
  ['iteration_5fcomplete_5fdata_15',['iteration_complete_data',['../structgko_1_1log_1_1iteration__complete__data.html',1,'gko::log']]],
  ['iterativebase_16',['IterativeBase',['../classgko_1_1solver_1_1IterativeBase.html',1,'gko::solver']]]
];

==> ginkgo-hpc-docs-1.8.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_8.js <==
var searchData=
[
  ['ic_0',['Ic',['../classgko_1_1factorization_1_1Ic.html',1,'gko::factorization::Ic&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Ic.html',1,'gko::preconditioner::Ic&lt; LSolverType, IndexType &gt;']]],
  ['identity_1',['Identity',['../classgko_1_1batch_1_1matrix_1_1Identity.html',1,'gko::batch::matrix::Identity&lt; ValueType &gt;'],['../classgko_1_1matrix_1_1Identity.html',1,'gko::matrix::Identity&lt; ValueType &gt;']]],
  ['identityfactory_2',['IdentityFactory',['../classgko_1_1matrix_1_1IdentityFactory.html',1,'gko::matrix']]],
  ['idr_3',['Idr',['../classgko_1_1solver_1_1Idr.html',1,'gko::solver']]],
  ['ilu_4',['Ilu',['../classgko_1_1factorization_1_1Ilu.html',1,'gko::factorization::Ilu&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Ilu.html',1,'gko::preconditioner::Ilu&lt; LSolverType, USolverType, ReverseApply, IndexType &gt;']]],
  ['imag_5foperation_5',['imag_operation',['../structgko_1_1accessor_1_1imag__operation.html',1,'gko::accessor']]],
  ['imag_5foperaton_6',['imag_operaton',['../structgko_1_1accessor_1_1imag__operaton.html',1,'gko::accessor']]],
  ['imbalance_5fbounded_5flimit_7',['imbalance_bounded_limit',['../classgko_1_1matrix_1_1Hybrid_1_1imbalance__bounded__limit.html',1,'gko::matrix::Hybrid']]],
  ['imbalance_5flimit_8',['imbalance_limit',['../classgko_1_1matrix_1_1Hybrid_1_1imbalance__limit.html',1,'gko::matrix::Hybrid']]],
  ['implicitresidualnorm_9',['ImplicitResidualNorm',['../classgko_1_1stop_1_1ImplicitResidualNorm.html',1,'gko::stop']]],
  ['index_5fmap_10',['index_map',['../structgko_1_1experimental_1_1distributed_1_1index__map.html',1,'gko::experimental::distributed']]],
  ['index_5fset_11',['index_set',['../classgko_1_1index__set.html',1,'gko']]],
  ['invalidstateerror_12',['InvalidStateError',['../classgko_1_1InvalidStateError.html',1,'gko']]],
  ['ir_13',['Ir',['../classgko_1_1solver_1_1Ir.html',1,'gko::solver']]],
  ['isai_14',['Isai',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['iteration_15',['Iteration',['../classgko_1_1stop_1_1Iteration.html',1,'gko::stop']]],
  ['iteration_5fcomplete_5fdata_16',['iteration_complete_data',['../structgko_1_1log_1_1iteration__complete__data.html',1,'gko::log']]],
  ['iterativebase_17',['IterativeBase',['../classgko_1_1solver_1_1IterativeBase.html',1,'gko::solver']]]
];
